@@ -1,3 +1,5 @@
 from scripts.deduplicate_music import deduplicate_music
 from scripts.invalid_filenames import rename_invalid_files
 from scripts.large_folders import large_folders
+from scripts.merge_online_local import merge_online_local
+from scripts.optimize_db import optimize_db
