@@ -98,8 +98,8 @@ def sanitize_url(args, path: str) -> str:
         subreddit = matches.groups()[0]
         return "https://old.reddit.com/r/" + subreddit + "/top/?sort=top&t=" + reddit_frequency(args.frequency)
 
-    if "m.youtube" in path:
-        return path.replace("m.youtube", "www.youtube")
+    if "/m." in path:
+        return path.replace("/m.", "/www.")
 
     return path
 
