@@ -5,7 +5,7 @@ from typing import Dict, Tuple
 
 from catt.api import CattDevice
 
-from xklb import consts, db, player, utils
+from xklb import consts, db, player, tube_backend, utils
 from xklb.consts import SC
 from xklb.player import get_ordinal_media, mark_media_deleted, override_sort
 from xklb.subtitle import externalize_subtitle
@@ -24,7 +24,7 @@ def construct_search_bindings(args, bindings, cf, columns) -> None:
 
 
 def construct_query(args) -> Tuple[str, dict]:
-    columns = args.db["media"].columns_dict
+    m_columns = args.db["media"].columns_dict
     cf = []
     bindings = {}
 
@@ -40,9 +40,9 @@ def construct_query(args) -> Tuple[str, dict]:
         if args.include:
             args.table = db.fts_search(args, bindings)
         elif args.exclude:
-            construct_search_bindings(args, bindings, cf, columns)
+            construct_search_bindings(args, bindings, cf, m_columns)
     else:
-        construct_search_bindings(args, bindings, cf, columns)
+        construct_search_bindings(args, bindings, cf, m_columns)
 
     if args.table == "media" and not args.print:
         limit = 60_000
@@ -66,7 +66,7 @@ def construct_query(args) -> Tuple[str, dict]:
         duration = "cast(length(tags) / 4.2 / 220 * 60 as INT) + 10 duration"
 
     cols = args.cols or ["path", "title", duration, "size", "sparseness", "subtitle_count", "is_dir"]
-    SELECT = "\n,".join([c for c in cols if c in columns])
+    SELECT = "\n,".join([c for c in cols if c in m_columns])
     LIMIT = "LIMIT " + str(args.limit) if args.limit else ""
     OFFSET = f"OFFSET {args.skip}" if args.skip else ""
     query = f"""SELECT
@@ -74,13 +74,16 @@ def construct_query(args) -> Tuple[str, dict]:
     FROM {args.table}
     WHERE 1=1
         {args.sql_filter}
+        {f'and path like "http%"' if args.safe else ''}
         {f'and path not like "%{args.keep_dir}%"' if args.post_action == 'askkeep' else ''}
-        {'and time_deleted=0' if 'time_deleted' in columns and 'time_deleted' not in args.sql_filter else ''}
+        {'and time_deleted=0' if 'time_deleted' in m_columns and 'time_deleted' not in args.sql_filter else ''}
+        {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
+        {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
     ORDER BY 1=1
-        {', time_downloaded > 0 desc' if 'time_downloaded' in columns and 'time_downloaded' not in args.sql_filter else ''}
-        {', video_count > 0 desc' if 'video_count' in columns and args.action == SC.watch else ''}
-        {', audio_count > 0 desc' if 'audio_count' in columns else ''}
-        {', width < height desc' if args.portrait and 'width' in columns else ''}
+        {', time_downloaded > 0 desc' if 'time_downloaded' in m_columns and 'time_downloaded' not in args.sql_filter else ''}
+        {', video_count > 0 desc' if 'video_count' in m_columns and args.action == SC.watch else ''}
+        {', audio_count > 0 desc' if 'audio_count' in m_columns else ''}
+        {', width < height desc' if args.portrait and 'width' in m_columns else ''}
         {f', subtitle_count {subtitle_count} desc' if args.action == SC.watch and not any([args.print,consts.PYTEST_RUNNING, 'subtitle_count' in args.where]) else ''}
         {', ' + args.sort if args.sort else ''}
         {', path' if args.print or args.include or args.play_in_order > 0 else ''}
@@ -389,6 +392,7 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
 
     parser.add_argument("--db", "-db", help=argparse.SUPPRESS)
     parser.add_argument("--ignore-errors", "--ignoreerrors", "-i", action="store_true", help=argparse.SUPPRESS)
+    parser.add_argument("--safe", "-safe", action="store_true", help="Skip generic URLs")
     parser.add_argument("--verbose", "-v", action="count", default=0)
 
     parser.add_argument(
@@ -499,14 +503,18 @@ def transcode(next_video):
 def play(args, m: Dict) -> None:
     media_file = m["path"]
 
+    if args.safe and not tube_backend.is_supported(m["path"]):
+        log.warning("[%s]: Unsupported URL (safe_mode)", m["path"])
+        return
+
     if is_play_in_order_lvl2(args, media_file):
         media_file = get_ordinal_media(args, media_file)
 
-    if args.action in (SC.watch, SC.listen):
+    if args.action in (SC.watch, SC.listen) and not media_file.startswith("http"):
         media_path = Path(args.prefix + media_file).resolve()
         if not media_path.exists():
             mark_media_deleted(args, media_file)
-            log.info("[%s]: Does not exist. Skipping...", media_file)
+            log.warning("[%s]: Does not exist. Skipping...", media_file)
             return
         media_file = str(media_path)
 
@@ -541,7 +549,7 @@ def play(args, m: Dict) -> None:
             if args.ignore_errors:
                 return
             else:
-                exit(r.returncode)
+                raise SystemExit(r.returncode)
 
         if args.action in (SC.listen, SC.watch):
             player.post_act(args, media_file)
