@@ -13,9 +13,14 @@ import screeninfo
 from rich.prompt import Confirm
 from tabulate import tabulate
 
-from xklb import consts, gui, utils
+from xklb import consts, utils
 from xklb.consts import SC
-from xklb.utils import cmd, cmd_interactive, human_time, log, os_bg_kwargs
+from xklb.utils import cmd, cmd_interactive, human_time, log
+
+try:
+    from xklb import gui
+except ModuleNotFoundError:
+    gui = None
 
 
 def generic_player(args) -> List[str]:
@@ -53,8 +58,12 @@ def calculate_duration(args, m) -> Tuple[int, int]:
 
 
 def find_xdg_application(media_file) -> Optional[str]:
-    mimetype = cmd("xdg-mime", "query", "filetype", media_file).stdout
-    default_application = cmd("xdg-mime", "query", "default", mimetype).stdout
+    if media_file.startswith("http"):
+        default_application = cmd("xdg-mime", "query", "default", "text/html").stdout
+    else:
+        mimetype = cmd("xdg-mime", "query", "filetype", media_file).stdout
+        default_application = cmd("xdg-mime", "query", "default", mimetype).stdout
+
     player_path = which(default_application.replace(".desktop", ""))
     return player_path
 
@@ -69,7 +78,9 @@ def parse(args, m=None, media_file=None) -> List[str]:
 
     elif args.action in (SC.read) and media_file:
         player_path = find_xdg_application(media_file)
-        log.info(player_path)
+        if player_path:
+            args.player_need_sleep = False
+            player = [player_path]
 
     elif mpv:
         args.player_need_sleep = False
@@ -100,7 +111,7 @@ def parse(args, m=None, media_file=None) -> List[str]:
                     player.extend([f"--end={end}"])
 
         if m and args.action == SC.watch:
-            if m["subtitle_count"] > 0:
+            if m.get("subtitle_count") and m["subtitle_count"] > 0:
                 player.extend(args.player_args_sub)
             elif m.get("time_partial_first") is not None or m["size"] > 500 * 1000000:  # 500 MB
                 pass
@@ -357,7 +368,8 @@ def listen_chromecast(args, m: dict) -> Optional[subprocess.CompletedProcess]:
     Path(consts.FAKE_SUBTITLE).touch()
     if args.with_local:
         cast_process = subprocess.Popen(
-            ["catt", "-d", args.chromecast_device, "cast", "-s", consts.FAKE_SUBTITLE, m["path"]], **os_bg_kwargs()
+            ["catt", "-d", args.chromecast_device, "cast", "-s", consts.FAKE_SUBTITLE, m["path"]],
+            **utils.os_bg_kwargs(),
         )
         sleep(0.974)  # imperfect lazy sync; I use keyboard shortcuts to send `set speed` commands to mpv for resync
         # if pyChromecast provides a way to sync accurately that would be very interesting to know; I have not researched it
@@ -405,28 +417,24 @@ def socket_play(args, m: dict) -> None:
     sleep(args.interdimensional_cable)
 
 
-def geom(x_size, y_size, x, y) -> List[str]:
-    return [f"--geometry={x_size}%x{y_size}%+{x}%+{y}%"]
-
-
-def geom_walk(v=1, h=1) -> List[List[str]]:
-    va = 100 // v
-    ha = 100 // h
+def geom_walk(display, v=1, h=1) -> List[List[int]]:
+    va = display.width // v
+    ha = display.height // h
 
     geoms = []
     for v_idx in range(v):
         for h_idx in range(h):
-            x = (100 // max(1, v - 1)) * v_idx
-            y = (100 // max(1, h - 1)) * h_idx
+            x = int(va * v_idx)
+            y = int(ha * h_idx)
             log.debug("geom_walk %s", dict(va=va, ha=ha, v_idx=v_idx, h_idx=h_idx, x=x, y=y))
-            geoms.append(geom(va, ha, x, y))
+            geoms.append([va, ha, x, y])
 
     return geoms
 
 
-def grid_stack(display, qty, swap=False) -> List[List[str]]:
+def grid_stack(display, qty, swap=False):
     if qty == 1:
-        return [[f'--screen-name="{display.name}"', "--fs", f'--fs-screen-name="{display.name}"']]
+        return [("--fs", f'--screen-name="{display.name}"', f'--fs-screen-name="{display.name}"')]
     else:
         dv = list(utils.divisor_gen(qty))
         if not dv:
@@ -441,8 +449,8 @@ def grid_stack(display, qty, swap=False) -> List[List[str]]:
     v, h = vh
     if swap:
         h, v = v, h
-    holes = geom_walk(v=v, h=h)
-    return [[f'--screen-name="{display.name}"', *hole] for hole in holes]
+    holes = geom_walk(display, v=v, h=h)
+    return [(hole, f'--screen-name="{display.name}"') for hole in holes]
 
 
 def get_display_by_name(displays, screen_name) -> List[screeninfo.Monitor]:
@@ -481,11 +489,11 @@ def get_multiple_player_template(args) -> List[str]:
 
     min_media_per_screen, remainder = divmod(args.multiple_playback, len(displays))
 
-    displays.sort(key=lambda d: d.width * d.height)
+    displays.sort(key=lambda d: d.width * d.height, reverse=True)
     players = []
     for d_idx, display in enumerate(displays):
         qty = min_media_per_screen
-        if remainder > 0 and (d_idx + 1) == len(displays):
+        if remainder > 0 and d_idx == 0:
             qty += remainder
 
         players.extend(grid_stack(display, qty, swap=is_hstack(args, display)))
@@ -501,13 +509,15 @@ def _create_player(args, window_geometry, media):
     mp_args = ["--window-scale=1", "--no-border", "--no-keepaspect-window"]
     return {
         **m,
-        "process": subprocess.Popen([*args.player, *mp_args, *window_geometry, "--", m["path"]], **os_bg_kwargs()),
+        "process": subprocess.Popen(
+            [*args.player, *mp_args, *window_geometry, "--", m["path"]], **utils.os_bg_kwargs()
+        ),
     }
 
 
-def gui_post_act(args, media, m):
-    if args.post_action in ("ask", "askkeep"):
-        r = gui.askkeep(m["path"], len(media))
+def gui_post_act(args, media, m, geom_data=None):
+    if gui and args.post_action in ("ask", "askkeep"):
+        r = gui.askkeep(m["path"], len(media), geom_data)
         if r == "DELETE":
             post_act(args, m["path"], action="delete")
         elif r == "KEEP" and args.post_action == "ask":
@@ -520,20 +530,32 @@ def gui_post_act(args, media, m):
         post_act(args, m["path"])
 
 
+def geom(x_size, y_size, x, y) -> str:
+    return f"--geometry={x_size}x{y_size}+{x}+{y}"
+
+
 def multiple_player(args, media) -> None:
     args.player = parse(args)
 
     template = get_multiple_player_template(args)
     players = []
 
-    try:  # pylint: disable=too-many-nested-blocks
-        while media:
-            for t_idx, player_hole in enumerate(template):
+    try:
+        while media or players:
+            for t_idx, t in enumerate(template):
+                if len(t) == 3:
+                    player_hole = t
+                    geom_data = None
+                else:
+                    geom_data, screen_name = t
+                    player_hole = [geom(*geom_data), screen_name]
+
                 try:
                     m = players[t_idx]
                 except IndexError:
                     log.debug("%s IndexError", t_idx)
-                    players.append(_create_player(args, player_hole, media))
+                    if media:
+                        players.append(_create_player(args, player_hole, media))
                 else:
                     log.debug("%s Check if still running", t_idx)
                     if m["process"].poll() is not None:
@@ -542,12 +564,15 @@ def multiple_player(args, media) -> None:
                             print("Player exited with code", r.returncode)
                             log.debug(join(r.args))
                             if not args.ignore_errors:
-                                exit(r.returncode)
+                                raise SystemExit(r.returncode)
 
                         if args.action in (SC.listen, SC.watch):
-                            gui_post_act(args, media, m)
+                            gui_post_act(args, media, m, geom_data)
 
-                        players[t_idx] = _create_player(args, player_hole, media)
+                        if media:
+                            players[t_idx] = _create_player(args, player_hole, media)
+                        else:
+                            del players[t_idx]
 
             log.debug("-- A dragon slumbers over its hoard of %s media --", len(media))
             sleep(0.2)  # I don't know if this is necessary but may as well~~
