@@ -245,15 +245,16 @@ def log_problem(args, playlist_path) -> None:
 
 
 def _add_playlist(args, playlist_path, pl: dict, media_path: Optional[str] = None) -> None:
+    extractor = safe_unpack(pl.get("ie_key"), pl.get("extractor_key"), pl.get("extractor"))
     playlist = {
-        "ie_key": safe_unpack(pl.get("ie_key"), pl.get("extractor_key"), pl.get("extractor")),
+        "ie_key": extractor,
         "title": pl.get("playlist_title"),
         "path": playlist_path,
         "uploader": safe_unpack(pl.get("playlist_uploader_id"), pl.get("playlist_uploader")),
         "id": pl.get("playlist_id"),
         "dl_config": args.dl_config,
         "time_deleted": 0,
-        "category": args.category,
+        "category": args.category or extractor,
         "profile": args.profile,
         **args.extra_playlist_data,
     }
@@ -261,19 +262,19 @@ def _add_playlist(args, playlist_path, pl: dict, media_path: Optional[str] = Non
     if not playlist.get("id") or media_path == playlist["path"]:
         log.warning("Importing playlist-less media %s", playlist["path"])
     else:
-        args.db["playlists"].upsert(playlist, pk="path", alter=True)
+        args.db["playlists"].upsert(utils.dict_filter_bool(playlist), pk="path", alter=True)
 
 
 def save_undownloadable(args, playlist_path):
     entry = {
         "path": playlist_path,
         "title": "No data from ydl.extract_info",
-        "category": args.category,
+        "category": args.category or "Uncategorized",
         "profile": args.profile,
         "dl_config": args.dl_config,
         **args.extra_playlist_data,
     }
-    args.db["playlists"].upsert(entry, pk="path", alter=True)
+    args.db["playlists"].upsert(utils.dict_filter_bool(entry), pk="path", alter=True)
 
 
 playlists_of_playlists = []
@@ -313,7 +314,7 @@ def process_playlist(args, playlist_path, ydl_opts, playlist_root=True) -> Optio
                         raise ExistingPlaylistVideoReached
 
                     entry = {**entry, **args.extra_media_data}
-                    args.db["media"].upsert(entry, pk="path", alter=True)
+                    args.db["media"].upsert(utils.dict_filter_bool(entry), pk="path", alter=True)
 
                     added_media_count += 1
                     if added_media_count > 1:
@@ -386,7 +387,7 @@ def get_extra_metadata(args, playlist_path, playlist_dl_opts=None) -> Optional[L
             entry["playlist_path"] = playlist_path
             entry["play_count"] = play_count
             entry["time_played"] = time_played
-            args.db["media"].upsert(entry, pk="path", alter=True)
+            args.db["media"].upsert(utils.dict_filter_bool(entry), pk="path", alter=True)
 
             current_video_count += 1
             sys.stdout.write("\033[K\r")
@@ -419,7 +420,7 @@ def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False)
             "time_deleted": consts.NOW if URE else 0,
             "error": error,
         }
-        args.db["media"].upsert(entry, pk="path", alter=True)  # type: ignore
+        args.db["media"].upsert(utils.dict_filter_bool(entry), pk="path", alter=True)  # type: ignore
         return
 
     assert info["local_path"] != ""
@@ -432,6 +433,8 @@ def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False)
             speech_recognition=False,
         )
         fs_tags = utils.dict_filter_bool(fs_extract.extract_metadata(fs_args, info["local_path"]), keep_0=False) or {}
+        for p in Path(consts.SUB_TEMP_DIR).glob("*.srt"):
+            p.unlink()
     else:
         fs_tags = {}
 
@@ -448,7 +451,7 @@ def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False)
         "time_deleted": consts.NOW if URE else 0,
         "error": error,
     }
-    args.db["media"].upsert(entry, pk="path", alter=True)  # type: ignore
+    args.db["media"].upsert(utils.dict_filter_bool(entry), pk="path", alter=True)  # type: ignore
 
     if fs_tags:
         args.db["media"].delete(webpath)
